==> haskell-unliftio-0.2.13.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio
version:              0.2.13.1
visibility:           public
id:                   unliftio-0.2.13.1-EuZFF1TfmeZ97SSTBWbQgh
key:                  unliftio-0.2.13.1-EuZFF1TfmeZ97SSTBWbQgh
license:              MIT
copyright:            2017 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio#readme

synopsis:
    The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)

description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>

category:             Control
abi:                  b425c83861b08d020e61928760dfeecb
exposed:              True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Foreign UnliftIO.IO UnliftIO.IO.File UnliftIO.IORef
    UnliftIO.Internals.Async UnliftIO.MVar UnliftIO.Memoize
    UnliftIO.Process UnliftIO.STM UnliftIO.Temporary UnliftIO.Timeout

hidden-modules:       Paths_unliftio UnliftIO.IO.File.Posix
import-dirs:          /usr/lib/ghc-8.10.2/site-local/unliftio-0.2.13.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/unliftio-0.2.13.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/unliftio-0.2.13.1
hs-libraries:         HSunliftio-0.2.13.1-EuZFF1TfmeZ97SSTBWbQgh
depends:
    async-2.2.2-LHbO9KOtule7TyL0aiG1ZW base-4.14.1.0
    bytestring-0.10.10.0 deepseq-1.4.4.0 directory-1.3.6.0
    filepath-1.4.2.1 process-1.6.9.0 stm-2.5.0.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:   /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html:         /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-0.2.13.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unliftio
version:              0.2.13.1
visibility:           public
id:                   unliftio-0.2.13.1-4b13P7nJKw37AduzBLsAZE
key:                  unliftio-0.2.13.1-4b13P7nJKw37AduzBLsAZE
license:              MIT
copyright:            2017 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio#readme

synopsis:
    The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)

description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>

category:             Control
abi:                  011cddd3551bcd12d37e5ee4aae90c8e
exposed:              True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Foreign UnliftIO.IO UnliftIO.IO.File UnliftIO.IORef
    UnliftIO.Internals.Async UnliftIO.MVar UnliftIO.Memoize
    UnliftIO.Process UnliftIO.STM UnliftIO.Temporary UnliftIO.Timeout

hidden-modules:       Paths_unliftio UnliftIO.IO.File.Posix
import-dirs:          /usr/lib/ghc-8.10.2/site-local/unliftio-0.2.13.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/unliftio-0.2.13.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/unliftio-0.2.13.1
hs-libraries:         HSunliftio-0.2.13.1-4b13P7nJKw37AduzBLsAZE
depends:
    async-2.2.2-fAglrfG9ui4HZbbDXwjGT base-4.14.1.0
    bytestring-0.10.10.0 deepseq-1.4.4.0 directory-1.3.6.0
    filepath-1.4.2.1 process-1.6.9.0 stm-2.5.0.0 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:   /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html:         /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
